/*  $Source: /u/maple/research/help/algcurves/RCS/Weierstrassform.i,v $   */
/*  $Notify: hoeij@sci.kun.nl $ */
\FUNCTION{Weierstrassform}{compute an isomorphism for function fields with genus 1}

\CALLINGSEQ
\callseqitem{Weierstrassform({\var f},{\var x},{\var y},{\var x0},{\var y0},{\var opt})}

\PARAMETERS
\paramitem{{f}}{a polynomial in x and y representing a curve of genus 1}
\paramitem{{\var x},{\var y},{\var x0},{\var y0}}{variables}
\paramitem{{\var opt}}{(optional) a sequence of options}

\SYNOPSIS
\synopsisitem{
   An algebraic function field Qbar(x)[y]/(f) where Qbar is the algebraic
   closure of Q is isomorphic to the field Qbar(x0)[y0]/(f0) where f0 is of
   the form y0^2 + square free polynomial in x0 of degree 3
   if and only if the genus is equal to 1.
   This procedure computes such an isomorphism.}

\synopsisitem{
    The output of genus is a list of 5 items containing:
\SQUOTE
    The curve f0
    The image of x0 under this isomorphism
    The image of y0 under this isomorphism
    The image of x under the inverse isomorphism
    The image of y under the inverse isomorphism
\EQUOTE
}

\synopsisitem{
 A regular point [x,y,z] on the curve can be specified as a 6'th argument.
   Then x0 and y0 will have their poles in this point on the curve. If the
   option `no inverse` is used then the inverse isomorphism is not
   computed. The option `Weierstrass` results in a Weierstrass normal form
   i.e. y0^2 - 4*x0^3 - a*x0 - b. If the option `j invariant` is specified
   then only the j-invariant is given.}


\EXAMPLES
\begin{mapleinput}
with(algcurves):
f:=x^4+y^4-2*x^3+x^2*y-2*y^3+x^2-x*y+y^2:
v:=Weierstrassform(f,x,y,x0,y0);
 # check if the image of x and y still satisfy the relation f in
 # the field Qbar(x0)[y0]/(f0)
subs({x=v[4],y=v[5]},f):
evala(subs(y0=RootOf(v[1],y0),%));
 # check if the image of x0 and y0 still satisfy the relation f0 in
 # the field Qbar(x)[y]/(f)
subs({x0=v[2],y0=v[3]},v[1]):
evala(subs(y=RootOf(f,y),%));
\end{mapleinput}

\SEEALSO{\xref{genus},\xref{j_invariant}}
