/*  $Source: /u/maple/research/help/algcurves/RCS/genus.i,v $   */
/*  $Notify: hoeij@sci.kun.nl $ */
\FUNCTION{genus}{Compute the genus of an algebraic curve}

\CALLINGSEQ
\callseqitem{genus({\var f},{\var x},{\var y},{\var opt})}

\PARAMETERS
\paramitem{{\var f}}{a squarefree polynomial specifying an algebraic curve}
\paramitem{{\var x,y}}{variables}
\paramitem{{\var opt}}{(optional) a sequence of options}

\SYNOPSIS
\synopsisitem{
  The genus of an irreducible algebraic curve is a nonnegative integer.
  However, if {\var f} is reducible this procedure could give a negative
  outcome. By default, this procedure does not check if f is irreducible.
  This default can be altered by giving the optional argument `irr check`.
  The polynomial {\var f} must be squarefree, otherwise an error message
  follows.
}

\EXAMPLES
\begin{mapleinput}
with(algcurves):
f:=x^2+x*y+y^2;
factor(f);         # It is irreducible in Q[x,y]
genus(f,x,y);      # The result is impossible for an irreducible curve
evala(AFactor(f)); # So f must be reducible over the algebraic numbers

f:=761328152*x^6*z^4-5431439286*x^2*y^8+2494*x^2*z^8+
 228715574724*x^6*y^4+9127158539954*x^10-15052058268*x^6*y^2*z^2+
 3212722859346*x^8*y^2-134266087241*x^8*z^2-202172841*y^8*z^2
 -34263110700*x^4*y^6-6697080*y^6*z^4-2042158*x^4*z^6-201803238*y^10+
 12024807786*x^4*y^4*z^2-128361096*x^4*y^2*z^4+506101284*x^2*z^2*y^6+
 47970216*x^2*z^4*y^4+660492*x^2*z^6*y^2-z^10-474*z^8*y^2-84366*z^6*y^4:
\end{mapleinput}

This f is a polynomial of degree 10 having a maximal number of cusps
according to the Plucker formulas. It was found by Rob Koelman. It has
26 cusps and no other singularities, hence the genus is 10.
\begin{mapleinput}
f:=subs(z=1,f);
genus(f,x,y);
\end{mapleinput}

\SEEALSO{\xref{singularities},\xref{parametrization}}
