/*  $Source: /u/maple/research/help/algcurves/RCS/integral_basis.i,v $   */
/*  $Notify: hoeij@sci.kun.nl $ */
\FUNCTION{integral_basis}{the integral basis of an algebraic function field}

\CALLINGSEQ
\callseqitem{integral_basis({\var a})}
\callseqitem{integral_basis({\var a},{\var x}}
\callseqitem{integral_basis({\var f},{\var x},{\var y})}

\PARAMETERS
\paramitem{{\var a}}{an algebraic function in RootOf form}
\paramitem{{\var x}}{a variable}
\paramitem{{\var y}}{a variable}
\paramitem{{f}}{a squarefree polynomial in x and y}

\SYNOPSIS
\synopsisitem{
 This procedure computes an integral basis for an algebraic function
 field. The algebraic function field is specified either by a RootOf a
 giving an algebraic extension L(x) subset L(x)[a], or 
 else by a minimal polynomial f of a in the variable y.
 This polynomial must be squarefree.
}

\synopsisitem{
The output is a list of elements of the function field which generate
(as a L[x] module) the integral closure of L[x] in the function field L(x)[a].
}

\synopsisitem{
If a contains no other parameters than x (so then L is an algebraic
extension of Q) then the second argument x is not necessary.}

\synopsisitem{
By setting infolevel[integral_basis] to a positive value some information will
be printed during the computation.
}

\synopsisitem{
The method used to compute an integral basis is based on Puiseux expansions. 
See the paper: "An algorithm for computing an integral basis in an algebraic
function field", J. of Symbolic Computation, 1994, 18, p. 353-363.}

\EXAMPLES
\begin{mapleinput}
with(algcurves):
alpha:=RootOf(x^3+7,x);
f:=y^8+3*x*y^5*alpha+5*x^4+x^6*alpha;
integral_basis(f,x,y);
\end{mapleinput}

integral_basis(RootOf(f,y)) does the same, except that the output
will be polynomials in RootOf(f,y) instead of in y.

\SEEALSO{\xref{puiseux},\xref{maxorder}}
