/*  $Source: /u/maple/research/help/algcurves/RCS/j_invariant.i,v $   */
/*  $Notify: hoeij@sci.kun.nl $ */
\FUNCTION{j_invariant}{compute the j invariant of an elliptic curve.}

\CALLINGSEQ
\callseqitem{j_invariant({\var f},{\var x},{\var y})}

\PARAMETERS
\paramitem{{f}}{a polynomial in x and y representing a curve of genus 1}
\paramitem{{\var x},{\var y}}{variables}

\SYNOPSIS
\synopsisitem{
   For algebraic curves with genus 1 one can compute a number called the
   j invariant. The main property of this j invariant is the following: two
   elliptic (this means: genus = 1) curves are birationally
   equivalent (i.e. can be transformed to each other with rational
   transformations over an algebraically closed field of constants)
   if and only if their j invariants are the same.}

\synopsisitem{
   The curve must be irreducible and have genus 1, otherwise the j invariant
   is not defined and this procedure will fail.}


\EXAMPLES
\begin{mapleinput}
with(algcurves):
f:=y^5+4/3-23/3*y^2+11*y^3-17/3*y^4-16/3*x^2+16/3*x^3-4/3*x^4:
 # Check that the genus is 1, because only then is the j invariant defined.
genus(f,x,y);
j_invariant(f,x,y);
\end{mapleinput}

\SEEALSO{\xref{genus},\xref{Weierstrassform}}
