/*  $Source: /u/maple/research/help/algcurves/RCS/parametrization.i,v $   */
/*  $Notify: hoeij@sci.kun.nl $ */
\FUNCTION{parametrization}{Compute a parametrization for a curve with genus 0}

\CALLINGSEQ
\callseqitem{parametrization({\var f},{\var x},{\var y},{\var t})}

\PARAMETERS
\paramitem{{f}}{a squarefree polynomial in x and y, with genus 0}
\paramitem{{\var x},{\var y},{\var t}}{variables}

\SYNOPSIS
\synopsisitem{
 This procedure computes, if it exists, a parametrization of an algebraic
 curve {\var f}. A parametrization is a birational equivalence from a
 projective line to the given curve {\var f}. Such a parametrization exists
 if and only if the genus is 0 and the curve is irreducible (which can be
 checked by AFactor).}

\synopsisitem{
The output of the procedure is a list [X(t),Y(t)] of rational functions
in {\var t}, such that [X(t),Y(t)] is a point on the curve {\var f} for
every value of {\var t} (although one can not use substitution for those
values of {\var t} for  which the denominator of X(t) or Y(t) vanishes).
}

\EXAMPLES
\begin{mapleinput}
with(algcurves):
f:=y^5+2*x*y^2+2*x*y^3+x^2*y-4*x^3*y+2*x^5:
v:=parametrization(f,x,y,t);
\end{mapleinput}
Now subs(t=any number,v) should be a point on the curve.
Test the result (this should be 0):
\begin{mapleinput}
normal(subs(x=v[1],y=v[2],f));
parametrization(x^4+y^4+a*x^2*y^2+b*y^3,x,y,t);
\end{mapleinput}

\SEEALSO{\xref{genus},\xref{AFactor}}
