/*  $Source: /u/maple/research/help/algcurves/RCS/plot_knot.i,v $   */
/*  $Notify: hoeij@sci.kun.nl $ */
\FUNCTION{plot_knot}{make a tubeplot for a singularity knot}

\CALLINGSEQ
\callseqitem{plot_knot({\var f},{\var x},{\var y},{\var opt})}

\PARAMETERS
\paramitem{{\var f}}{an algebraic curve with a singularity at the point 0}
\paramitem{{\var x,y}}{variables}
\paramitem{{\var opt}}{(optional) a sequence of options}

\SYNOPSIS
\synopsisitem{
  Let f be a polynomial in x and y giving an algebraic curve in the plane C^2
  with a singularity at the point (x,y)=(0,0).
  The output of this procedure is called the singularity knot of
  this singularity. This knot is defined as follows:
   By identifying
   C^2 with R^4 the curve can be viewed as a 2 dimensional surface over the
   real numbers. This procedure computes the intersection of this surface with
   a sphere in R^4 with radius epsilon and center 0. The intersection consists
   of a number of closed curves over the real numbers. After applying a
   projection from the sphere (is 3 dimensional over R) to R^3 these curves can
   be plotted by the tubeplot command in the plots package. Such a plot gives
   information about the singularity of f in the point 0. See also:
   E. Brieskorn, H. Kn"orrer: Ebene Algebraische Kurven, Birkh"auser 1981.
}


\synopsisitem{
The curve given by f need not be irreducible, but f must be squarefree otherwise
this procedure does not work.
}

\synopsisitem{
  If printlevel > 1 the number of branches will be printed to the screen. Each
  branch (i.e. place above the point 0) corresponds to one component in the
  knot.
}

\synopsisitem{
OPTIONS:

   epsilon:    the radius of the sphere. The default is 1. If there are
               other singularities near 0 then a smaller number must be chosen,
               because the picture is not correct if there is more than 1
               singularity inside the sphere.

   colours:    Specifying a list of colours results in a plot where each
               branch gets its own colour.

   The options for tubeplot can be used as well. In plot_knot these
   options have the following default values: numpoints=150, radius=0.05,
   tubepoints=5, scaling=CONSTRAINED and style=PATCHNOGRID.
}

\EXAMPLES
\begin{mapleinput}
with(algcurves):
printlevel:=2:
\end{mapleinput}
\begin{fakeinput}
 plot_knot(y^2-x^3,x,y);
 f:=(y^3-x^7)*(y^2-2*x^5);
 plot_knot(f,x,y,epsilon=0.8,radius=0.03,colours=[blue,red]);
 plot_knot(f+y^3,x,y,epsilon=0.8);
 plot_knot(f+y^3,y,x,epsilon=0.8); # Same knot, but it looks
  # different because the projection point is different now
  # that x and y are switched.
 f:=(y^3-x^7)*(y^2-2*x^5)*(y^2+2*x^5);
 plot_knot(f,y,x,epsilon=0.8,radius=0.03,colours=[blue,red,pink]);
 g:=(y^3-x^7)*(y^3-x^7+100*x^13)*(y^3-x^7-100*x^13);
 plot_knot(g,x,y,epsilon=0.8,radius=0.03,numpoints=250,
  colours=[blue,red,green]);
\end{fakeinput}

\SEEALSO{\xref{tubeplot}}
