/*  $Source: /u/maple/research/help/algcurves/RCS/puiseux.i,v $   */
/*  $Notify: hoeij@sci.kun.nl $ */
\FUNCTION{puiseux}{determines the Puiseux expansions of an algebraic function}

\CALLINGSEQ
\callseqitem{puiseux({\var a},{\var x}={\var p},{\var n})}
\callseqitem{puiseux({\var f},{\var x}={\var p},{\var y},{\var n})}
\callseqitem{puiseux({\var f},{\var x}={\var p},{\var y},{\var n},{\var T})}

\PARAMETERS
\paramitem{{\var a}}{an algebraic function in RootOf form}
\paramitem{{\var x}={\var p}}{gives the point
  around which the expansions are computed}
\paramitem{{\var n}}{a number specifying the desired accuracy of the expansions}
\paramitem{{\var y}}{a variable}
\paramitem{{\var f}}{a squarefree polynomial in x and y}
\paramitem{{\var T}}{(optional) a variable, used for obtaining a different output syntax}

\SYNOPSIS
\synopsisitem{
 A polynomial {\var f} of degree N in the variable y with coefficients in a
 field L({\var x}) has N roots in the algebraic closure of the field
 L(({\var x}-{\var p})). These roots are called the Puiseux expansions of
 {\var f} at {\var x}={\var p}.
 Each Puiseux expansion is of the form Sum(a_i * (x-p)^(i/r),i=-N..infinity)
 for some integer r (r is called the ramification index of the Puiseux
 expansion), and some integer N and elements a_i in the algebraic
 closure of L.
}

\synopsisitem{
 The polynomial {\var f} must be squarefree, otherwise the puiseux
 procedure does not work.
}

\synopsisitem{
  If {\var f} is irreducible then {\var f} gives an algebraic extension
  L({\var x})[{\var y}]/({\var f}) of L(x). Instead of giving {\var f},
  this algebraic extension can also be specified with a RootOf {\var a}
  of {\var f}. This {\var a} can be viewed as a multivalued function
  of {\var x}. The Puiseux expansions give the local expansions of this
  multivalued function.
}

\synopsisitem{
  The procedure puiseux determines the field L from {\var a} or {\var f}.
  The groundfield L of the computation is the smallest field such that
  {\var f} is in L({\var x})[{\var y}].
}

\synopsisitem{
  The Puiseux expansions are only computed up to conjugation over
  L(({\var x}-{\var p})). So
  if a number of expansions are algebraically conjugated over
  L(({\var x}-{\var p})) then only one of these expansions is given.
}

\synopsisitem{
  The Puiseux expansions are computed modulo x^n. So if for instance
  n=10, then the term x^(49/5) would be computed, but not the term x^10.

  If n=0 then the expansions are not computed modulo x^0, but in this case
  the number of terms that is computed is precisely the number that is
  needed to distinguish the expansions from the other expansions.
  If n is the string `minimal` then the same output is given.
}

\synopsisitem{
  To avoid an output containing fractional powers of {\var x} one can
  specify a fifth argument {\var T}. Then the Puiseux expansions in the
  output are represented in a different way, namely as

  [{\var x} = (a constant)*(a power of {\var T}) ,  {\var y} = a power series in {\var T}].

  So then {\var x} and {\var y} are expressed in terms of a local parameter.
}

\synopsisitem{
  NOTE: The Maple "alias" function does not recognize an alias in terms of
  another alias. Therefore, you must not use nested aliasses for algebraic
  numbers because then the puiseux algorithm is not able to construct the
  field L over which the algebraic function is defined.
}

\EXAMPLES
\begin{mapleinput}
with(algcurves):
alpha:=RootOf(x^3+7);
f:=y^8+x*y^5+x^4-x^6*alpha;
puiseux(f,x=0,y,0);    # is the same as puiseux(RootOf(f,y),x=0,0);
puiseux(f,x=0,y,5);
\end{mapleinput}

To get all 8 Puiseux expansions substitute all conjugates
over L((x)) of x^(1/5) and (-x)^(1/3) in this set.

\SEEALSO{\xref{series}}
