/*  $Source: /u/maple/research/help/algcurves/RCS/singularities.i,v $   */
/*  $Notify: hoeij@sci.kun.nl $ */
\FUNCTION{singularities}{Compute the singularities of an algebraic curve}

\CALLINGSEQ
\callseqitem{singularities({\var f},{\var x},{\var y})}

\PARAMETERS
\paramitem{{\var f}}{a polynomial specifying an algebraic curve}
\paramitem{{\var x,y}}{variables}

\SYNOPSIS
\synopsisitem{
Let {\var f} be squarefree polynomial in {\var x} and {\var y}. Then
{\var f} defines an algebraic curve in the plane C^2, and also in the
projective plane P^2 by making {\var f} homogeneous. This procedure computes
the singular points of the curve in the projective plane. The points are
given by homogeneous co-ordinates [X,Y,Z].

For each singularity this procedure also computes the multiplicity and
the delta invariant.
}

\synopsisitem{
The output of this procedure is a set consisting of lists of the following form
[ point , multiplicity  , delta invariant].
}

\synopsisitem{
This procedure computes all singularities up to conjugation. So if
a singularity [RootOf(_Z^2-2),1,1] is given in the output, and if
RootOf(_Z^2-2) does not appear in the input, then [-RootOf(_Z^2-2),1,1]
is a singular point as well but will not be given in the output.
}

\synopsisitem{
The genus of a curve is the number (d-1)*(d-2)/2 - Sum(delta invariants)
where d is the degree of the curve.
Note that if we apply this formula to compute the genus, then for each
singularity we must multiply the delta invariant by the degree of the
algebraic extension over which the singularity is defined, because only 1
singularity of each conjugacy class is given in the output.
}

\EXAMPLES
\begin{mapleinput}
with(algcurves):
f:=-8*y^5-207*y*x^4+180*x^5-35*y^4-128*y^3*x+621*y*x^3-450*x^4+
 82*y^3-521*y*x^2+369*x^3-19*y^2+135*y*x-100*x^2-28*y-7*x+8;
degree(f,{x,y});
singularities(f,x,y);
\end{mapleinput}

Note that the conjugate (replace RootOf(_Z^2+1) by -RootOf(_Z^2+1))
is also a singularity. So the genus is (5-1)*(5-2)/2-1-1-1-2*1=1

\SEEALSO{\xref{puiseux},\xref{genus},\xref{singular}}
